let vscode = {};
if(typeof acquireVsCodeApi === 'function'){
    vscode = acquireVsCodeApi();
}


let callbacks = {};

function callVscode(data, cb) {
    if (typeof data === 'string') {
        data = { cmd: data };
    }
    if (cb) {
        // 时间戳加上5位随机数
        const cbid = Date.now() + '' + Math.round(Math.random() * 100000);
        callbacks[cbid] = cb;
        data.cbid = cbid;
    }
    vscode.postMessage(data);
}

window.addEventListener('message', (event) => {
    const message = event.data;
    switch (message.cmd) {
        case 'vscodeCallback':
            (callbacks[message.cbid] || function () {})(message.data);
            delete callbacks[message.cbid];
            break;
        default:
            break;
    }
});
new Vue({
    el: '#app',
    data: function(){
        return {
            form: {
                bindnumber: '',
                env: '1', // 1 测试 2 环境
                path: '',
                clearData: '0',
                size: 0
            },
            packageName: '',
            clickAction: false,
        }
    },
    mounted() {
        callVscode({ cmd: 'getRpkPath' }, (args) => {
            this.form.path = args.rpk;
            this.form.size = args.size;
        });
        callVscode({cmd: 'getConfig'}, args => {
            console.log(args.data);
            if(args.data){
                let data = JSON.parse(args.data);
                this.form.bindnumber = data.bindnumber;
                this.form.env = data.env;
                this.form.clearData = data.clearData;
            }
        })
    },
    computed:{
        domain(){
            return this.form.env === '1' ? 'https://store-module.okii.com': 'https://store.watch.okii.com/appstore';
        },
        domainText(){
            return this.form.env === '1' ? '测试环境': '正式环境';
        }
    },
    methods: {
        uploadFile() {
            if(this.clickAction){
                return this.$message.error('10秒内请勿频繁提交');
            }
            if (!this.form.bindnumber) {
                return this.$message.error('请输入绑定号');
            }
            if (!this.form.path.endsWith('.rpk')) {
                return this.$message.error('请选择 rpk 文件');
            }
            if (!this.form.size > 524288) {
                return this.$message.error('rpk 包大小不能超过 512KB');
            }
            this.clickAction = true;
            setTimeout(()=>{
                this.clickAction = false;
            },10000)
            this.form.bindnumber = this.form.bindnumber.replace(/，/g, ',');
            callVscode({ 
                cmd: 'uploadFile',
                bindnumber: this.form.bindnumber,
                clearData: this.form.clearData,
                domain: this.domain,
                address: this.form.path
            }, (args) => {
                console.log(args);
                if(args.body.code === '000001'){
                    this.$message.success(`${this.domainText}上传成功，请留意手表应用是否安装成功`);
                }else{
                    this.handleErrorCode(args.body.code);
                }
            });
            callVscode({
                cmd: 'createConfig',
                bindnumber: this.form.bindnumber,
                clearData: this.form.clearData,
                env: this.form.env
            })
        },
        uninstall(){
            if(this.clickAction){
                return this.$message.error('10秒内请勿频繁提交');
            }
            if (!this.form.bindnumber) {
                return this.$message.error('请输入绑定号');
            }
            if (!this.packageName) {
                return this.$message.error('请输入应用包名');
            }
            this.clickAction = true;
            setTimeout(()=>{
                this.clickAction = false;
            },10000)
            let bindnumber = this.form.bindnumber.split(',');
            callVscode({ 
                cmd: 'uninstall',
                bindnumber: bindnumber,
                packageName: this.packageName,
                domain: this.domain
            }, (args) => {
                console.log(args);
                if(args.body.code === '000001'){
                    this.$message.success(`${this.domainText}卸载指令发出成功，请留意手表应用是否卸载成功`);
                }else{
                    this.handleErrorCode(args.body.code);
                }
            });
        },
        selectRpk() {
            callVscode({ cmd: 'selectRpk' }, (args) => {
                this.form.path = args.uris[0].path;
            });
        },
        handleErrorCode(code){
            switch(code){
                case '000052':
                    this.$message.error('绑定号不存在，请检查绑定号是否正确');
                    break;
                case '000053':
                    this.$message.error('请求失败，该绑定号没有权限');
                    break;
                case '000054':
                    this.$message.error('请求失败，文件大小不能超出512K');
                    break;
                case '000055':
                    this.$message.error('文件传输失败');
                    break;
                case '000056':
                    this.$message.error('请求失败，文件后缀必须为rpk');
                    break;
                case '000057':
                    this.$message.error('请求失败，上传的包中解析不到包名、版本号、版本名称');
                    break;
                case '000058':
                    this.$message.error('请求失败，上传文件名不能为空');
                    break;
                case '000059':
                    this.$message.error('请求失败，绑定号已经被拉入黑名单中');
                    break;
                default:
                    this.$message.error('请求失败，错误码为'+code);
            }
        }
    }
});
